Stan Math Library: stan/math/prim/scal/fun/lgamma.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

lgamma.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_LGAMMA_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_LGAMMA_HPP
3
4 #include <boost/math/special_functions/gamma.hpp>
5
6 namespace stan {
7
8 namespace math {
9
30 // throws domain_error if x is at pole
31 double lgamma(double x) {
32 return boost::math::lgamma(x);
33 }
34
35 }
36 }
37
38 #endif
stan::math::lgamma
fvar< T > lgamma(const fvar< T > &x)
Definition: lgamma.hpp:15
stan
Definition: log_sum_exp.hpp:8
stan::math::lgamma
var lgamma(const stan::math::var &a)
The log gamma function for variables (C99).
Definition: lgamma.hpp:35

[ Stan Home Page ] © 2011–2016, Stan Development Team.